Crate dia_assert [−] [src]
A small kit for confirming user actions via command line
Project
- Repository: https://bitbucket.org/haibison/dia-assert
- License: Free Public License 1.0.0
- This project follows Semantic Versioning 2.0.0
Features
For important tasks, if you want to confirm the user, you can use Assert. It generates a string and asks the user to type it. You can
catch if the user fails, and process with your solution. Or you can let Assert exit the process peacefully via process::exit().
Structs
| Assert |
Use this struct with
|
Enums
| Failed |
Failed. |
| Level |
Level. |
Constants
| CRATE_CODE_NAME |
Crate code name. |
| CRATE_NAME |
Crate name. |
| CRATE_RELEASE_DATE |
Crate release date (year/month/day). |
| CRATE_VERSION_NAME |
Crate version name. |
| TAG |
Tag, which can be used for logging... |
| UUID |
Unique universally identifier of this crate. Its CRC-32 is
|
Functions
| try_n |
Tries
|
| try_n_with |
Tries
|
| try_once |
Tries once. |
| try_once_with |
Tries once. |