[][src]Enum dia_assert::Level

pub enum Level {
    Low,
    Normal,
    Medium,
    High,
    Critical,
}

Level

For important tasks, if you want to confirm the user, you can use hash() to generate a random string, and ask them to type it.

Variants

LowNormalMediumHighCritical

Methods

impl Level[src]

pub fn hash(&self) -> String[src]

Generates a random hash string based on current level

Notes

  • On non-Unix systems, this function will generate a random string based on current time.

  • On Unix systems, it will try to read some bytes from /dev/urandom. If any error raises, it reverts back to above method. Also:

    • For security reason, if it detects some abnormal attributes from that file, it will print warnings to stderr, and will not read any bytes.

    • If reading succeeds, as a nice gesture, it will write some bytes back to that file.

  • Higher levels always generate longer strings.

They might look like these:

Level Sample
Low e9
Normal ac8c
Medium db9c-725a
High dca9-e93c-f8b2
Critical 115a-a983-4c11-4a38